# coding: utf-8

import logging
import os
from typing import AnyStr, Optional

from . import utils


def install(cwd: bool = False, path: Optional[AnyStr] = None, no_ssl: bool = False):
    """
    Appends the directory of the chromedriver binary file to PATH.

    :param cwd: Flag indicating whether to download to current working directory. If the `cwd` is True, then path argument will be ignored.
    :param path: Specify the path where the Chrome driver will be installed. If the `cwd` value is True, this value is ignored.
    :param no_ssl: Determines whether or not to use the encryption protocol when downloading the chrome driver.
    :return: The file path of chromedriver
    """
    if cwd:
        path = os.getcwd()
    chromedriver_filepath = utils.download_chromedriver(path, no_ssl)
    if not chromedriver_filepath:
        logging.debug("Can not download chromedriver.")
        return
    chromedriver_dir = os.path.dirname(chromedriver_filepath)
    if "PATH" not in os.environ:
        os.environ["PATH"] = chromedriver_dir
    elif chromedriver_dir not in os.environ["PATH"]:
        os.environ["PATH"] = (
            chromedriver_dir + utils.get_variable_separator() + os.environ["PATH"]
        )
    return chromedriver_filepath


def get_chrome_version():
    """
    Get installed version of chrome on client

    :return: The version of chrome
    """
    return utils.get_chrome_version()



# coding: utf-8
import os
import sys

from setuptools import setup

__author__ = "Yeongbin Jo <iam.yeongbin.jo@gmail.com>"


with open("README.md") as readme_file:
    long_description = readme_file.read()


# 'setup.py publish' shortcut.
if sys.argv[-1] == "publish":
    os.system("python3 setup.py sdist bdist_wheel")
    os.system("twine upload dist/*")
    sys.exit()
elif sys.argv[-1] == "clean":
    import shutil

    if os.path.isdir("build"):
        shutil.rmtree("build")
    if os.path.isdir("dist"):
        shutil.rmtree("dist")
    if os.path.isdir("chromedriver_autoinstaller.egg-info"):
        shutil.rmtree("chromedriver_autoinstaller.egg-info")


setup(
    name="chromedriver-autoinstaller",
    version="0.4.1",
    author="Yeongbin Jo",
    author_email="iam.yeongbin.jo@gmail.com",
    description="Automatically install chromedriver that supports the currently installed version of chrome.",
    license="MIT",
    keywords="chromedriver chrome chromium selenium",
    url="https://github.com/yeongbin-jo/python-chromedriver-autoinstaller",
    packages=["chromedriver_autoinstaller"],
    entry_points={
        "console_scripts": [
            "chromedriver-path=chromedriver_autoinstaller.utils:print_chromedriver_path"
        ],
    },
    long_description_content_type="text/markdown",
    long_description=long_description,
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Topic :: Software Development :: Testing",
        "Topic :: System :: Installation/Setup",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
)
